# coding: utf-8
from setuptools import setup, find_packages

setup(
    name             = 'VisualPython',
    version          = '0.1.1',
    packages         = find_packages(),
    description      = 'VisualPython',
    license          = '',
    author           = 'BlackLogic',
    author_email     = 'blacklogic.dev@gmail.com',
    url              = 'https://gitlab.com/blacklogic.dev/visualpython',
    download_url     = 'https://gitlab.com/blacklogic.dev/visualpython/visualpython.0.1.tar.gz',
    install_requires = [],
    classifiers      = ['Programming Language :: Python :: 3.6',
                        'Programming Language :: Python :: 3.7']
    )
